
from flask import Blueprint
from flask import current_app
from flask import request
from werkzeug.exceptions import abort

from capsulflask.db import get_model, my_exec_info_message

bp = Blueprint("hub", __name__, url_prefix="/hub")

def authorized_for_host(id):
  auth_header_value = request.headers.get('Authorization').replace("Bearer ", "")
  return get_model().authorized_for_host(id, auth_header_value)

@bp.route("/heartbeat/<string:host_id>", methods=("POST"))
def heartbeat(host_id):
  if authorized_for_host(host_id):
    get_model().host_heartbeat(host_id)
  else:
    current_app.logger.info(f"/hub/heartbeat/{host_id} returned 401: invalid token")
    return abort(401, "invalid host id or token")

@bp.route("/claim-operation/<int:operation_id>/<string:host_id>", methods=("POST"))
def claim_operation(operation_id: int, host_id: str):
  if authorized_for_host(host_id):
    exists = get_model().host_operation_exists(operation_id, host_id)
    if not exists:
      return abort(404, "host operation not found")
    claimed = get_model().claim_operation(operation_id, host_id)
    if claimed:
      return "ok"
    else:
      return abort(409, "operation was already assigned to another host")
  else:
    current_app.logger.info(f"/hub/claim-operation/{operation_id}/{host_id} returned 401: invalid token")
    return abort(401, "invalid host id or token")

